# safrac 
Fractal generator for geophysical models (fractal volumes and surfaces).

## Install
 * Install directly from pip or run `pip install .` inside the source directory

## Notes for developers

### Versioning
 * Versioning is done using git.
 * The primary repository is at [github.com](https://github.com/cstatz/safrac)

### Coding style
 * We try to adhere to [Python PEP8](https://www.python.org/dev/peps/pep-0008/)
 * If you use PyCharm: activate the PEP8 compliance check
